@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,11 +30,21 @@
 
 import logging
 import traceback
+import os
+import os.path
 
 from miro import app
 from miro import config
 from miro.plat import options
 
+def get_renderer_list():
+    d = os.path.dirname(__file__)
+    contents = os.listdir(d)
+    # FIXME - this sucks.  switch this to use extensions.
+    contents = [m for m in contents if m.endswith("renderer.py")]
+    contents = [m[:-11] for m in contents]
+    return contents
+
 def set_renderer(modname):
     """Attempt to set the video renderer."""
 
@@ -47,7 +57,7 @@ def set_renderer(modname):
         app.movie_data_program_info = module.movie_data_program_info
         app.get_item_type = module.get_item_type
         logging.info("set_renderer: successfully loaded %s", modname)
-    except:
+    except StandardError:
         logging.info("set_renderer: couldn't load %s: %s", modname,
                 traceback.format_exc())
         raise
@@ -66,14 +76,14 @@ def init_renderer():
     try:
         set_renderer("%srenderer" % r)
         return
-    except:
+    except StandardError:
         logging.exception("init_renderer: error detected...  trying to use gstreamerrenderer")
 
     try:
         # try to add the gstreamer renderer if the preferences aren't right
         set_renderer("gstreamerrenderer")
         return
-    except:
+    except StandardError:
         logging.exception("init_renderer: no valid renderer has been loaded")
     app.audio_renderer = None
     app.video_renderer = None
