@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -39,7 +39,8 @@ import locale
 import urllib
 import sys
 import time
-from miro.util import returnsUnicode, returnsBinary, checkU, checkB, call_command
+from miro.util import (returns_unicode, returns_binary, check_u, check_b,
+                       call_command)
 import miro
 from miro.plat import options
 
@@ -49,10 +50,8 @@ FilenameType = str
 # very easy.
 from os.path import samefile
 
-
 # this is used in portable/gtcache.py
-localeInitialized = True
-
+_locale_initialized = False
 
 def get_available_bytes_for_movies():
     """Helper method used to get the free space on the disk where downloaded
@@ -92,10 +91,13 @@ def confirm_ui_thread():
         print "ui function called from thread %s" % threading.currentThread()
         traceback.print_stack()
 
+def locale_initialized():
+    return _locale_initialized
 
-# gettext understands *NIX locales, so we don't have to do anything
-def initializeLocale():
-    pass
+def initialize_locale():
+    # gettext understands *NIX locales, so we don't have to do anything
+    global _locale_initialized
+    _locale_initialized = True
 
 def setup_logging(inDownloader=False):
     if inDownloader:
@@ -121,13 +123,13 @@ def setup_logging(inDownloader=False):
         logging.getLogger('').addHandler(rotater)
         rotater.doRollover()
 
-@returnsBinary
+@returns_binary
 def utf8_to_filename(filename):
     if not isinstance(filename, str):
         raise ValueError("filename is not a str")
     return filename
 
-@returnsBinary
+@returns_binary
 def unicodeToFilename(filename, path=None):
     """Takes in a unicode string representation of a filename (NOT a file
     path) and creates a valid byte representation of it attempting to preserve
@@ -136,9 +138,9 @@ def unicodeToFilename(filename, path=None):
     Note: This is not guaranteed to give the same results every time it is run,
     nor is it guaranteed to reverse the results of filenameToUnicode.
     """
-    @returnsUnicode
+    @returns_unicode
     def shortenFilename(filename):
-        checkU(filename)
+        check_u(filename)
         first, last = os.path.splitext(filename)
 
         if first:
@@ -146,9 +148,9 @@ def unicodeToFilename(filename, path=None):
 
         return unicode(last[:-1])
 
-    checkU(filename)
+    check_u(filename)
     if path:
-        checkB(path)
+        check_b(path)
     else:
         path = os.getcwd()
 
@@ -175,7 +177,7 @@ def unicodeToFilename(filename, path=None):
 
     return new_filename
 
-@returnsUnicode
+@returns_unicode
 def filenameToUnicode(filename, path=None):
     """Given a filename in raw bytes, return the unicode representation
 
@@ -183,8 +185,8 @@ def filenameToUnicode(filename, path=None):
     not is it guaranteed to reverse the results of unicodeToFilename.
     """
     if path:
-        checkB(path)
-    checkB(filename)
+        check_b(path)
+    check_b(filename)
     try:
         return filename.decode(locale.getpreferredencoding())
     except (SystemExit, KeyboardInterrupt):
@@ -192,59 +194,31 @@ def filenameToUnicode(filename, path=None):
     except:
         return filename.decode('ascii', 'replace')
 
-# Takes filename given by the OS and turn it into a FilenameType
-def osFilenameToFilenameType(filename):
-    return FilenameType(filename)
-
-# Takes an array of filenames given by the OS and turn them into a FilenameTypes
-def osFilenamesToFilenameTypes(filenames):
-    return [osFilenameToFilenameType(filename) for filename in filenames]
-
-# Takes a FilenameType and turn it into something the OS accepts.
-def filenameTypeToOSFilename(filename):
-    return filename
-
-@returnsUnicode
-def makeURLSafe(s, safe='/'):
+@returns_unicode
+def make_url_safe(s, safe='/'):
     """Takes in a byte string or a unicode string and does the right thing
     to make a URL
     """
     if isinstance(s, str):
         # quote the byte string
         return urllib.quote(s, safe=safe).decode('ascii')
-    else:
-        try:
-            return urllib.quote(s.encode(locale.getpreferredencoding()), safe=safe).decode('ascii')
-        except (SystemExit, KeyboardInterrupt):
-            raise
-        except:
-            return s.decode('ascii', 'replace')
 
-@returnsBinary
-def unmakeURLSafe(s):
-    """Undoes makeURLSafe (assuming it was passed a filenameType)
+    try:
+        return urllib.quote(s.encode(locale.getpreferredencoding()), safe=safe).decode('ascii')
+    except (SystemExit, KeyboardInterrupt):
+        raise
+    except:
+        return s.decode('ascii', 'replace')
+
+@returns_binary
+def unmake_url_safe(s):
+    """Undoes make_url_safe (assuming it was passed a filenameType)
     """
     # unquote the byte string
-    checkU(s)
+    check_u(s)
     return urllib.unquote(s.encode('ascii'))
 
-_convert_path_cache = None
-
-@returnsBinary
-def findConvert():
-    global _convert_path_cache
-
-    if _convert_path_cache != None:
-        return _convert_path_cache
-
-    search_path = os.environ.get('PATH', os.defpath)
-    for d in search_path.split(os.pathsep):
-        convert_path = os.path.join(d, 'convert')
-        if os.path.exists(convert_path):
-            _convert_path_cache = convert_path
-    return _convert_path_cache
-
-def pidIsRunning(pid):
+def pid_is_running(pid):
     if pid is None:
         return False
     try:
@@ -253,15 +227,15 @@ def pidIsRunning(pid):
     except OSError, err:
         return err.errno == errno.EPERM
 
-def killProcess(pid):
+def kill_process(pid):
     if pid is None:
         return
-    if pidIsRunning(pid):
+    if pid_is_running(pid):
         try:
             os.kill(pid, signal.SIGTERM)
             for i in xrange(100):
                 time.sleep(.01)
-                if not pidIsRunning(pid):
+                if not pid_is_running(pid):
                     return
             os.kill(pid, signal.SIGKILL)
         except (SystemExit, KeyboardInterrupt):
@@ -269,10 +243,10 @@ def killProcess(pid):
         except:
             logging.exception("error killing download daemon")
 
-def launchDownloadDaemon(oldpid, env):
+def launch_download_daemon(oldpid, env):
     # Use UNIX style kill
-    if oldpid is not None and pidIsRunning(oldpid):
-        killProcess(oldpid)
+    if oldpid is not None and pid_is_running(oldpid):
+        kill_process(oldpid)
 
     environ = os.environ.copy()
     environ['MIRO_FRONTEND'] = options.frontend
