@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -32,16 +32,6 @@
 ## Paths and configuration                                                   ##
 ###############################################################################
 
-# The xine hack helps older systems.  See bug #7132.
-#
-# If this hack is enabled and Miro crashes at the end of playback when
-# the xine renderer is used, then try disabling the hack.
-#
-# As of Miro 2.0, there is a command-line option to enable/disable the 
-# hack.
-USE_XINE_HACK = False
-
-
 # The following properties allow you to explicitly set xulrunner paths and
 # library names in the case that Miro guesses them wrong for your system.
 # When setting these, you must make sure that:
@@ -116,16 +106,24 @@ XPCOM_LIB = None
 GTKMOZEMBED_LIB = None
 XULRUNNER_19 = None
 
-# The name of the boost python library.  Used for building extensions.
-# If this is set to None, setup.py will divine the right lib to use.
-# It should probably be either "boost_python" or "boost_python-mt".
-BOOST_LIB = None
-
 
 ###############################################################################
 ## End of configuration. No user-serviceable parts inside                    ##
 ###############################################################################
 
+import sys
+
+# verify we have required bits for compiling Miro
+
+try:
+    from Pyrex.Compiler import Version
+    if Version.version.split(".") < ["0", "9", "6", "4"]:
+        print "Pyrex 0.9.6.4 or greater required.  You have version %s." % Version.version
+        sys.exit(1)
+except ImportError:
+    print "Pyrex not found.  Please install Pyrex."
+    sys.exit(1)
+
 from distutils.cmd import Command
 from distutils.core import setup
 from distutils.extension import Extension
@@ -139,7 +137,6 @@ import os
 import pwd
 import subprocess
 import platform
-import sys
 import re
 import time
 import shutil
@@ -166,22 +163,18 @@ def get_root_dir():
         root_try = os.path.abspath(os.path.join(root_try, '..'))
     return root_dir
 
-def is_x64():
-    return platform.machine() == "x86_64" or platform.machine() == "amd64"
-
 root_dir = get_root_dir()
 portable_dir = os.path.join(root_dir, 'portable')
 portable_frontend_dir = os.path.join(portable_dir, 'frontends')
 portable_xpcom_dir = os.path.join(portable_frontend_dir, 'widgets', 'gtk',
-        'xpcom')
+                                  'xpcom')
 dl_daemon_dir = os.path.join(portable_dir, 'dl_daemon')
 test_dir = os.path.join(portable_dir, 'test')
 resource_dir = os.path.join(root_dir, 'resources')
 platform_dir = os.path.join(root_dir, 'platform', 'gtk-x11')
 platform_package_dir = os.path.join(platform_dir, 'plat')
 platform_widgets_dir = os.path.join(platform_package_dir, 'frontends',
-        'widgets')
-xine_dir = os.path.join(platform_dir, 'xine')
+                                    'widgets')
 
 # insert the root_dir to the beginning of sys.path so that we can
 # pick up portable and other packages
@@ -243,7 +236,6 @@ def get_command_output(cmd, warnOnStderr=True, warnOnReturnCode=True):
     """Wait for a command and return its output.  Check for common errors and
     raise an exception if one of these occurs.
     """
-
     p = subprocess.Popen(cmd, shell=True, close_fds=True,
                          stdout=subprocess.PIPE, stderr=subprocess.PIPE)
     stdout, stderr = p.communicate()
@@ -294,31 +286,13 @@ def parse_pkg_config(command, components, options_dict = None):
 
     return options_dict
 
-all_libs = []
-if os.path.exists(os.path.join(sysconfig.PREFIX, "lib")):
-    all_libs.extend(os.listdir(os.path.join(sysconfig.PREFIX, "lib")))
-if os.path.exists(os.path.join(sysconfig.PREFIX, "lib64")):
-    all_libs.extend(os.listdir(os.path.join(sysconfig.PREFIX, "lib64")))
-all_libs = [mem for mem in all_libs if mem.startswith("libboost")]
-
-def mt_or_not(s, all_libs=all_libs):
-    for mem in all_libs:
-        if mem.startswith("lib%s-mt" % s):
-            print "Using %s-mt" % s
-            return "%s-mt" % s
-    print "using %s" % s
-    return s
-
-if BOOST_LIB is None:
-    BOOST_LIB = mt_or_not("boost_python")
-else:
-    print "Using %s" % BOOST_LIB
-
-def compile_xine_extractor():
-    rv = os.system("gcc %s -o %s `pkg-config --libs --cflags gdk-pixbuf-2.0 glib-2.0 libxine`" %
-                   (os.path.join(platform_dir, "xine/xine_extractor.c"), os.path.join(platform_dir, "xine/xine_extractor")))
-    if rv != 0:
-        raise RuntimeError("xine_extractor compilation failed.  Possibly missing libxine, gdk-pixbuf-2.0, or glib-2.0.")
+def package_exists(package_name):
+    """
+    Return True if the package is present in the system.  False otherwise.
+    The check is made with pkg-config.
+    """
+    # pkg-config returns 0 if the package is present
+    return subprocess.call(['pkg-config', '--exists', package_name]) == 0
 
 def generate_miro(xpcom_path):
     # build a miro script that wraps the miro.real script with an LD_LIBRARY_PATH
@@ -361,90 +335,8 @@ fi
     f.close()
 
 
-#### The fasttypes extension ####
-fasttypes_ext = \
-    Extension("miro.fasttypes",
-        sources = [os.path.join(portable_dir, 'fasttypes.cpp')],
-        libraries = [BOOST_LIB],
-    )
-
-
-##### The libtorrent extension ####
-def fetch_sources(portable_dir):
-    sources = []
-    for root, dirs, files in os.walk(os.path.join(portable_dir, 'libtorrent')):
-        if '.svn' in dirs:
-            dirs.remove('.svn')
-        for file in files:
-            if file.endswith('.cpp') or file.endswith('.c'):
-                sources.append(os.path.join(root, file))
-    return sources
-
-def get_libtorrent_extension(portable_dir):
-    libtorrent_installed = False
-    try:
-        ret = parse_pkg_config("pkg-config", "libtorrent-rasterbar")
-        import libtorrent
-        libtorrent_installed = True
-        print "libtorrent-rasterbar (0.13 or later) and python bindings are installed--using system version."
-        return None
-    except RuntimeError:
-        print "libtorrent-rasterbar not installed on this system."
-    except ImportError:
-        print "python bindings for libtorrent-rasterbar not installed on this system"
-
-    include_dirs = [os.path.join(portable_dir, x) for x in
-                            ['libtorrent/include', 'libtorrent/include/libtorrent']]
-
-    extra_compile_args = ["-Wno-missing-braces",
-                          "-D_FILE_OFFSET_BITS=64",
-                          "-DHAVE___INCLUDE_LIBTORRENT_ASIO_HPP=1",
-                          "-DHAVE___INCLUDE_LIBTORRENT_ASIO_SSL_STREAM_HPP=1",
-                          "-DHAVE___INCLUDE_LIBTORRENT_ASIO_IP_TCP_HPP=1",
-                          "-DHAVE_PTHREAD=1", "-DTORRENT_USE_OPENSSL=1", "-DHAVE_SSL=1",
-                          "-DNDEBUG=1", "-O2"]
-
-    if is_x64():
-        extra_compile_args.append("-DAMD64")
-
-    libraries = ['z', 'pthread', 'ssl']
-
-    # get mt or non-mt versions of the boost libraries
-    libraries += [mt_or_not("boost_python"),
-                  mt_or_not("boost_filesystem"),
-                  mt_or_not("boost_date_time"),
-                  mt_or_not("boost_thread")]
-
-    config_vars = sysconfig.get_config_vars()
-    if "CFLAGS" in config_vars and "-Wstrict-prototypes" in config_vars["CFLAGS"]:
-        config_vars["CFLAGS"] = config_vars["CFLAGS"].replace("-Wstrict-prototypes", " ")
-
-    if "OPT" in config_vars and "-Wstrict-prototypes" in config_vars["OPT"]:
-        config_vars["OPT"] = config_vars["OPT"].replace("-Wstrict-prototypes", " ")
-
-    sources = fetch_sources(portable_dir)
-
-    # versions of libtorrent prior to 0.14 have this file which we don't want to
-    # compile or use
-    if os.path.exists(os.path.join(portable_dir, "libtorrent", "src", "file_win.cpp")):
-        sources.remove(os.path.join(portable_dir, "libtorrent", "src", "file_win.cpp"))
-
-    return Extension("miro.libtorrent",
-                     include_dirs=include_dirs,
-                     libraries=libraries,
-                     extra_compile_args=extra_compile_args,
-                     sources=sources)
-
-libtorrent_ext = get_libtorrent_extension(portable_dir)
-
-
 #### MozillaBrowser Extension ####
 def get_mozilla_stuff():
-    try:
-        packages = get_command_output("pkg-config --list-all")
-    except RuntimeError, error:
-        sys.exit("Package config error:\n%s" % (error,))
-
     if XPCOM_LIB and GTKMOZEMBED_LIB and XULRUNNER_19 != None:
         print "\nUsing XPCOM_LIB, GTKMOZEMBED_LIB and XULRUNNER_19 values...."
         xulrunner19 = XULRUNNER_19
@@ -454,29 +346,31 @@ def get_mozilla_stuff():
     else:
         print "\nTrying to figure out xpcom_lib, gtkmozembed_lib, and xulrunner_19 values...."
         xulrunner19 = False
-        if re.search("^libxul", packages, re.MULTILINE):
+        if package_exists('libxul'):
             xulrunner19 = True
             xpcom_lib = 'libxul'
             gtkmozembed_lib = 'libxul'
 
-        elif re.search("^xulrunner-xpcom", packages, re.MULTILINE):
+        elif package_exists('xulrunner-xpcom'):
             xpcom_lib = 'xulrunner-xpcom'
             gtkmozembed_lib = 'xulrunner-gtkmozembed'
 
-        elif re.search("^seamonkey-xpcom", packages, re.MULTILINE):
+        elif package_exists('seamonkey-xpcom'):
             xpcom_lib = 'seamonkey-xpcom'
             gtkmozembed_lib = 'seamonkey-gtkmozembed'
 
-        elif re.search("^mozilla-xpcom", packages, re.MULTILINE):
+        elif package_exists('mozilla-xpcom'):
             xpcom_lib = 'mozilla-xpcom'
             gtkmozembed_lib = 'mozilla-gtkmozembed'
 
-        elif re.search("^firefox-xpcom", packages, re.MULTILINE):
+        elif package_exists('firefox-xpcom'):
             xpcom_lib = 'firefox-xpcom'
             gtkmozembed_lib = 'firefox-gtkmozembed'
 
         else:
-            sys.exit("Can't find libxul, xulrunner-xpcom, seamonkey-xpcom, mozilla-xpcom or firefox-xpcom")
+            print "Can't find libxul, xulrunner-xpcom, seamonkey-xpcom, mozilla-xpcom or firefox-xpcom"
+            print "One of these is required."
+            sys.exit(1)
 
     print "using xpcom_lib: ", repr(xpcom_lib)
     print "using gtkmozembed_lib: ", repr(gtkmozembed_lib)
@@ -613,28 +507,6 @@ pluginsdir_ext = \
     )
 
 
-#### Xine Extension ####
-xine_options = parse_pkg_config('pkg-config',
-        'libxine pygtk-2.0 gtk+-2.0 glib-2.0 gthread-2.0')
-
-# If you get XINE crashes, uncommenting this might fix it. It's
-# necessary on Debian Etch and Ubuntu Feisty right now.
-#
-# We have a horrible workaround for buggy X drivers in xine_impl.c
-# controlled by this variable
-if USE_XINE_HACK:
-    print "Using the Xine driver hack. If you experience trouble playing video,\n   try setting USE_XINE_HACK to False in setup.py."
-    if xine_options.has_key('define_macros'):
-        xine_options['define_macros'].append(('INCLUDE_XINE_DRIVER_HACK', '1'))
-    else:
-        xine_options['define_macros'] = [('INCLUDE_XINE_DRIVER_HACK', '1')]
-
-xine_ext = Extension('miro.xine', [
-                         os.path.join(xine_dir, 'xine.pyx'),
-                         os.path.join(xine_dir, 'xine_impl.c'),],
-                     **xine_options)
-
-
 #### Build the data_files list ####
 def listfiles(path):
     return [f for f in glob(os.path.join(path, '*')) if os.path.isfile(f)]
@@ -673,15 +545,12 @@ data_files += [
      [os.path.join(platform_dir, 'miro.1.gz')]),
     ('/usr/share/man/man1',
      [os.path.join(platform_dir, 'miro.real.1.gz')]),
-    ('/usr/lib/miro/',
-     [os.path.join(platform_dir, 'xine/xine_extractor')]),
 ]
 
 
 # if we're not doing "python setup.py clean", then we can do a bunch of things
 # that have file-related side-effects
 if not "clean" in sys.argv:
-    compile_xine_extractor()
     generate_miro(xpcom_runtime_path)
     # gzip the man page
     os.system ("gzip -9 < %s > %s" % (os.path.join(platform_dir, 'miro.1'), os.path.join(platform_dir, 'miro.1.gz')))
@@ -840,17 +709,12 @@ class clean(Command):
             shutil.rmtree('./dist/')
 
 ext_modules = []
-ext_modules.append(fasttypes_ext)
-ext_modules.append(xine_ext)
 ext_modules.append(xlib_ext)
-if libtorrent_ext:
-    ext_modules.append(libtorrent_ext)
 ext_modules.append(pygtkhacks_ext)
 ext_modules.append(mozprompt_ext)
 ext_modules.append(httpobserver_ext)
 ext_modules.append(windowcreator_ext)
 ext_modules.append(pluginsdir_ext)
-ext_modules.append(Extension("miro.sorts", [os.path.join(portable_dir, 'sorts.pyx')]))
 
 #### Run setup ####
 setup(name='miro',
