@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,25 +26,28 @@
 # this exception statement from your version. If you delete this exception
 # statement from all source files in the program, then also delete it here.
 
-from base64 import b64encode
-from miro.gtcache import gettext as _
+import datetime
 import os
+import random
+import logging
+from base64 import b64encode
 
+from miro.gtcache import gettext as _
 from miro.database import DDBObject, ObjectNotFoundError
 from miro.dl_daemon import daemon, command
-from miro.download_utils import nextFreeFilename, getFileURLPath, filterDirectoryName
-from miro.util import get_torrent_info_hash, returnsUnicode, checkU, returnsFilename, unicodify, checkF, toUni
-# from miro import app
+from miro.download_utils import (next_free_filename, get_file_url_path,
+                                 filter_directory_name)
+from miro.util import (get_torrent_info_hash, returns_unicode, check_u,
+                       returns_filename, unicodify, check_f, to_uni)
 from miro import config
 from miro import dialogs
+from miro import displaytext
 from miro import eventloop
 from miro import httpclient
 from miro import models
 from miro import prefs
-import random
 from miro.plat.utils import samefile, FilenameType, unicodeToFilename
 from miro import flashscraper
-import logging
 from miro import fileutil
 
 daemon_starter = None
@@ -52,16 +55,17 @@ daemon_starter = None
 # a hash of download ids that the server knows about.
 _downloads = {}
 
-# Returns an HTTP auth object corresponding to the given host, path or
-# None if it doesn't exist
 def find_http_auth(host, path, realm=None, scheme=None):
-    checkU(host)
-    checkU(path)
+    """Returns an HTTP auth object corresponding to the given host, path or
+    None if it doesn't exist
+    """
+    check_u(host)
+    check_u(path)
     if realm:
-        checkU(realm)
+        check_u(realm)
     if scheme:
-        checkU(scheme)
-    #print "Trying to find HTTPAuth with host %s, path %s, realm %s, and scheme %s" %(host,path,realm,scheme)
+        check_u(scheme)
+    # print "Trying to find HTTPAuth with host %s, path %s, realm %s, and scheme %s" %(host,path,realm,scheme)
     for obj in HTTPAuthPassword.make_view():
         if (obj.host == host and path.startswith(obj.path) and
                 (realm is None or obj.realm == realm) and
@@ -69,15 +73,15 @@ def find_http_auth(host, path, realm=None, scheme=None):
             return obj
     return None
 
-
 class HTTPAuthPassword(DDBObject):
-    def setup_new(self, username, password, host, realm, path, authScheme=u"Basic"):
-        checkU(username)
-        checkU(password)
-        checkU(host)
-        checkU(realm)
-        checkU(path)
-        checkU(authScheme)
+    def setup_new(self, username, password, host, realm, path,
+                  authScheme=u"Basic"):
+        check_u(username)
+        check_u(password)
+        check_u(host)
+        check_u(realm)
+        check_u(path)
+        check_u(authScheme)
         oldAuth = find_http_auth(host, path, realm, authScheme)
         while not oldAuth is None:
             oldAuth.remove()
@@ -99,8 +103,8 @@ class HTTPAuthPassword(DDBObject):
         self.confirm_db_thread()
         return self.authScheme
 
-totalUpRate = 0
-totalDownRate = 0
+total_up_rate = 0
+total_down_rate = 0
 
 def get_downloader_by_dlid(dlid):
     try:
@@ -108,7 +112,7 @@ def get_downloader_by_dlid(dlid):
     except ObjectNotFoundError:
         return None
 
-@returnsUnicode
+@returns_unicode
 def generate_dlid():
     dlid = u"download%08d" % random.randint(0, 99999999)
     while get_downloader_by_dlid(dlid=dlid):
@@ -118,9 +122,9 @@ def generate_dlid():
 class RemoteDownloader(DDBObject):
     """Download a file using the downloader daemon."""
     def setup_new(self, url, item, contentType=None, channelName=None):
-        checkU(url)
+        check_u(url)
         if contentType:
-            checkU(contentType)
+            check_u(contentType)
         self.origURL = self.url = url
         self.itemList = []
         self.child_deleted = False
@@ -130,10 +134,10 @@ class RemoteDownloader(DDBObject):
         self.metainfo = self.fast_resume_data = None
         self.state = u'downloading'
         if contentType is None:
-            # HACK:  Some servers report the wrong content-type for torrent
-            # files.  We try to work around that by assuming if the enclosure
-            # states that something is a torrent, it's a torrent.
-            # Thanks to j@v2v.cc
+            # HACK: Some servers report the wrong content-type for
+            # torrent files.  We try to work around that by assuming
+            # if the enclosure states that something is a torrent,
+            # it's a torrent.  Thanks to j@v2v.cc.
             if item.enclosure_type == u'application/x-bittorrent':
                 contentType = item.enclosure_type
         self.contentType = u""
@@ -141,6 +145,7 @@ class RemoteDownloader(DDBObject):
         self.channelName = channelName
         self.manualUpload = False
         self._save_later_dc = None
+        self._update_retry_time_dc = None
         if contentType is None:
             self.contentType = u""
         else:
@@ -154,7 +159,7 @@ class RemoteDownloader(DDBObject):
     @classmethod
     def finished_view(cls):
         return cls.make_view("state in ('finished', 'uploading', "
-                "'uploading-paused')")
+                             "'uploading-paused')")
 
     @classmethod
     def auto_uploader_view(cls):
@@ -173,36 +178,37 @@ class RemoteDownloader(DDBObject):
         """Downloaders with no items associated with them."""
         return cls.make_view('id NOT IN (SELECT downloader_id from item)')
 
-    def signal_change(self, needsSave=True, needsSignalItem=True):
-        DDBObject.signal_change(self, needsSave=needsSave)
+    def signal_change(self, needs_save=True, needsSignalItem=True):
+        DDBObject.signal_change(self, needs_save=needs_save)
         if needsSignalItem:
             for item in self.itemList:
-                item.signal_change(needsSave=False)
-        if needsSave:
+                item.signal_change(needs_save=False)
+        if needs_save:
             self._cancel_save_later()
 
 
     def _save_later(self):
         """Save the remote downloader at some point in the future.
 
-        This is used to handle the fact that remote downloaders are updated
-        often, but those updates are usually just the status dict, which is
-        never used for SELECT statements.  Continually saving those changes
-        to disk is just a waste of time and IO.
+        This is used to handle the fact that remote downloaders are
+        updated often, but those updates are usually just the status
+        dict, which is never used for SELECT statements.  Continually
+        saving those changes to disk is just a waste of time and IO.
 
-        Instead, we schedule the save to happen sometime in the future.  When
-        miro quits, we call the module-level function run_delayed_saves(),
-        which makes sure any pending objects are saved to disk.
+        Instead, we schedule the save to happen sometime in the
+        future.  When miro quits, we call the module-level function
+        run_delayed_saves(), which makes sure any pending objects are
+        saved to disk.
         """
         if self._save_later_dc is None:
             self._save_later_dc = eventloop.addTimeout(15,
                     self._save_now, "Delayed RemoteDownloader save")
 
     def _save_now(self):
-        """If _save_later() was called and we haven't saved the downloader to
-        disk, do it now.
+        """If _save_later() was called and we haven't saved the
+        downloader to disk, do it now.
         """
-        if self.idExists() and self._save_later_dc is not None:
+        if self.id_exists() and self._save_later_dc is not None:
             self.signal_change()
 
     def _cancel_save_later(self):
@@ -211,14 +217,15 @@ class RemoteDownloader(DDBObject):
             self._save_later_dc = None
 
     def on_content_type(self, info):
-        if not self.idExists():
+        if not self.id_exists():
             return
 
         if info['status'] == 200:
             self.url = info['updated-url'].decode('ascii','replace')
             self.contentType = None
             try:
-                self.contentType = info['content-type'].decode('ascii','replace')
+                self.contentType = info['content-type'].decode('ascii',
+                                                               'replace')
             except (SystemExit, KeyboardInterrupt):
                 raise
             except:
@@ -229,7 +236,7 @@ class RemoteDownloader(DDBObject):
             self.on_content_type_error(error)
 
     def on_content_type_error(self, error):
-        if not self.idExists():
+        if not self.id_exists():
             return
 
         self.status['state'] = u"failed"
@@ -238,9 +245,9 @@ class RemoteDownloader(DDBObject):
         self.signal_change()
 
     def get_content_type(self):
-        httpclient.grabHeaders(self.url,
-                               self.on_content_type, self.on_content_type_error)
- 
+        httpclient.grabHeaders(self.url, self.on_content_type,
+                               self.on_content_type_error)
+
     @classmethod
     def initialize_daemon(cls):
         RemoteDownloader.dldaemon = daemon.ControllerDaemon()
@@ -254,23 +261,25 @@ class RemoteDownloader(DDBObject):
         return (0, 0)
 
     def before_changing_status(self):
-        global totalDownRate
-        global totalUpRate
+        global total_down_rate
+        global total_up_rate
         rates = self._get_rates()
-        totalDownRate -= rates[0]
-        totalUpRate -= rates[1]
+        total_down_rate -= rates[0]
+        total_up_rate -= rates[1]
 
     def after_changing_status(self):
-        global totalDownRate
-        global totalUpRate
+        global total_down_rate
+        global total_up_rate
+        self._recalc_state()
         rates = self._get_rates()
-        totalDownRate += rates[0]
-        totalUpRate += rates[1]
+        total_down_rate += rates[0]
+        total_up_rate += rates[1]
 
     @classmethod
     def update_status(cls, data):
         for field in data:
-            if field not in ['filename', 'shortFilename', 'channelName', 'metainfo', 'fastResumeData']:
+            if field not in ['filename', 'shortFilename', 'channelName',
+                             'metainfo', 'fastResumeData']:
                 data[field] = unicodify(data[field])
         self = get_downloader_by_dlid(dlid=data['dlid'])
         # print data
@@ -283,13 +292,12 @@ class RemoteDownloader(DDBObject):
             try:
                 if current == new:
                     return
-            except Exception, e:
-                # This is a known bug with the way we used to save fast resume
-                # data
-                print "WARNING exception when comparing status: %s" % e
+            except Exception:
+                # This is a known bug with the way we used to save
+                # fast resume data
+                logging.exception("RemoteDownloader.update_status: exception when comparing status")
 
-            old_state = self.state
-            wasFinished = self.isFinished()
+            wasFinished = self.is_finished()
             old_filename = self.get_filename()
             self.before_changing_status()
 
@@ -309,18 +317,25 @@ class RemoteDownloader(DDBObject):
             self._recalc_state()
 
             # Store the time the download finished
-            finished = self.isFinished() and not wasFinished
-            file_migrated = (self.isFinished() and
+            finished = self.is_finished() and not wasFinished
+            file_migrated = (self.is_finished() and
                     self.get_filename() != old_filename)
             needsSignalItem = not (finished or file_migrated)
             self.after_changing_status()
 
-            if self.get_state() == u'uploading' and not self.manualUpload and self.getUploadRatio() > 1.5:
-                self.stopUpload()
+            if ((self.get_state() == u'uploading'
+                 and not self.manualUpload
+                 and (config.get(prefs.LIMIT_UPLOAD_RATIO)
+                      and self.get_upload_ratio() > config.get(prefs.UPLOAD_RATIO)))):
+                self.stop_upload()
 
             self.signal_change(needsSignalItem=needsSignalItem,
-                    needsSave=False)
-            if self.state == old_state:
+                               needs_save=False)
+            if self.changed_attributes == set(('status',)):
+                # if we just changed status, then we can wait a while
+                # to store things to disk.  Since we go through
+                # update_status() often, this results in a fairly
+                # large performance gain and alleviates #12101
                 self._save_later()
             else:
                 self.signal_change()
@@ -336,15 +351,18 @@ class RemoteDownloader(DDBObject):
         flashscraper.try_scraping_url(self.url, self._run_downloader)
 
     def _run_downloader(self, url, contentType = None):
-        if not self.idExists():
-            return # we got deleted while we were doing the flash scraping
+        if not self.id_exists():
+            # we got deleted while we were doing the flash scraping
+            return
         if contentType is not None:
             self.contentType = contentType
         if url is not None:
             self.url = url
-            logging.debug("downloading url %s" % self.url)
+            logging.debug("downloading url %s", self.url)
             c = command.StartNewDownloadCommand(RemoteDownloader.dldaemon,
-                                                self.url, self.dlid, self.contentType, self.channelName)
+                                                self.url, self.dlid,
+                                                self.contentType,
+                                                self.channelName)
             c.send()
             _downloads[self.dlid] = self
         else:
@@ -356,7 +374,8 @@ class RemoteDownloader(DDBObject):
     def pause(self):
         """Pauses the download."""
         if _downloads.has_key(self.dlid):
-            c = command.PauseDownloadCommand(RemoteDownloader.dldaemon, self.dlid)
+            c = command.PauseDownloadCommand(RemoteDownloader.dldaemon,
+                                             self.dlid)
             c.send()
         else:
             self.before_changing_status()
@@ -381,25 +400,28 @@ class RemoteDownloader(DDBObject):
             self.signal_change()
 
     def delete(self):
-        try:
+        if "filename" in self.status:
             filename = self.status['filename']
-        except KeyError:
+        else:
             return
         try:
             fileutil.delete(filename)
         except OSError:
-            logging.exception("Error deleting downloaded file: %s", toUni(filename))
+            logging.exception("Error deleting downloaded file: %s",
+                              to_uni(filename))
 
-        parent = os.path.join(fileutil.expand_filename(filename), os.path.pardir)
+        parent = os.path.join(fileutil.expand_filename(filename),
+                              os.path.pardir)
         parent = os.path.normpath(parent)
         moviesDir = fileutil.expand_filename(config.get(prefs.MOVIES_DIRECTORY))
-        if (os.path.exists(parent) and os.path.exists(moviesDir) and
-                not samefile(parent, moviesDir) and
-                len(os.listdir(parent)) == 0):
+        if ((os.path.exists(parent) and os.path.exists(moviesDir)
+             and not samefile(parent, moviesDir)
+             and len(os.listdir(parent)) == 0)):
             try:
                 os.rmdir(parent)
             except OSError:
-                logging.exception("Error deleting empty download directory: %s", toUni(parent))
+                logging.exception("Error deleting empty download directory: %s",
+                                  to_uni(parent))
 
     def start(self):
         """Continues a paused, stopped, or failed download thread
@@ -433,32 +455,28 @@ class RemoteDownloader(DDBObject):
             c.send()
         else:
             # downloader doesn't have our dlid.  Move the file ourself.
-            try:
-                shortFilename = self.status['shortFilename']
-            except KeyError:
-                print """\
-WARNING: can't migrate download because we don't have a shortFilename!
-URL was %s""" % self.url
+            shortFilename = self.status.get("shortFilename")
+            if not shortFilename:
+                logging.warning("can't migrate download; no shortfilename!  URL was %s", self.url)
                 return
-            try:
-                filename = self.status['filename']
-            except KeyError:
-                print """\
-WARNING: can't migrate download because we don't have a filename!
-URL was %s""" % self.url
+            filename = self.status.get("filename")
+            if not filename:
+                logging.warning("can't migrate download; no filename!  URL was %s", self.url)
                 return
             if fileutil.exists(filename):
-                if 'channelName' in self.status and self.status['channelName'] is not None:
-                    channelName = filterDirectoryName(self.status['channelName'])
-                    directory = os.path.join (directory, channelName)
-                try:
-                    fileutil.makedirs(directory)
-                except OSError:
-                    pass
+                if self.status.get('channelName', None) is not None:
+                    channelName = filter_directory_name(self.status['channelName'])
+                    directory = os.path.join(directory, channelName)
+                if not os.path.exists(directory):
+                    try:
+                        fileutil.makedirs(directory)
+                    except OSError:
+                        # FIXME - what about permission issues?
+                        pass
                 newfilename = os.path.join(directory, shortFilename)
                 if newfilename == filename:
                     return
-                newfilename = nextFreeFilename(newfilename)
+                newfilename = next_free_filename(newfilename)
                 def callback():
                     self.status['filename'] = newfilename
                     self.signal_change(needsSignalItem=False)
@@ -470,7 +488,7 @@ URL was %s""" % self.url
     def _file_migrated(self, old_filename):
         # Make sure that itemList is populated with items, see (#12202)
         for item in models.Item.downloader_view(self.id):
-            self.addItem(item)
+            self.add_item(item)
         for item in self.itemList:
             item.on_downloader_migrated(old_filename, self.get_filename())
 
@@ -480,17 +498,17 @@ URL was %s""" % self.url
     def set_channel_name(self, channelName):
         if self.channelName is None:
             if channelName:
-                checkF(channelName)
+                check_f(channelName)
             self.channelName = channelName
 
     def remove(self):
         """Removes downloader from the database and deletes the file.
         """
-        global totalDownRate
-        global totalUpRate
+        global total_down_rate
+        global total_up_rate
         rates = self._get_rates()
-        totalDownRate -= rates[0]
-        totalUpRate -= rates[1]
+        total_down_rate -= rates[0]
+        total_up_rate -= rates[1]
         self.stop(self.deleteFiles)
         DDBObject.remove(self)
 
@@ -501,12 +519,12 @@ URL was %s""" % self.url
         self.confirm_db_thread()
         if self.contentType == u'application/x-bittorrent':
             return u"bittorrent"
-        else:
-            return u"http"
 
-    def addItem(self, item):
-        """In case multiple downloaders are getting the same file, we can support
-        multiple items
+        return u"http"
+
+    def add_item(self, item):
+        """In case multiple downloaders are getting the same file, we
+        can support multiple items
         """
         if item not in self.itemList:
             self.itemList.append(item)
@@ -514,7 +532,7 @@ URL was %s""" % self.url
                 self.main_item_id = item.id
                 self.signal_change()
 
-    def removeItem(self, item):
+    def remove_item(self, item):
         self.itemList.remove(item)
         if len (self.itemList) == 0:
             self.remove()
@@ -522,82 +540,103 @@ URL was %s""" % self.url
             self.main_item_id = self.itemList[0].id
             self.signal_change()
 
-    def getRate(self):
+    def get_rate(self):
         self.confirm_db_thread()
         return self.status.get('rate', 0)
 
-    def getETA(self):
+    def get_eta(self):
         self.confirm_db_thread()
         return self.status.get('eta', 0)
 
-    @returnsUnicode
+    @returns_unicode
     def get_startup_activity(self):
         self.confirm_db_thread()
         activity = self.status.get('activity')
+        if (activity is None and self.status.get('retryCount', -1) > -1 and
+                'retryTime' in self.status):
+            activity = self._calc_retry_time()
+            if self._update_retry_time_dc is None:
+                self._update_retry_time_dc = eventloop.addTimeout(1,
+                        self._update_retry_time, 'Updating retry time')
         if activity is None:
             return _("starting up")
-        else:
-            return activity
+        return activity
 
-    @returnsUnicode
-    def getReasonFailed(self):
-        """Returns the reason for the failure of this download
-        This should only be called when the download is in the failed state
+    def _calc_retry_time(self):
+        retry_delta = self.status['retryTime'] - datetime.datetime.now()
+        time_str = displaytext.time_string(retry_delta.seconds)
+        return _('no connection - retrying in %s') % time_str
+
+    def _update_retry_time(self):
+        if self.id_exists():
+            # calling signal_change() will cause the us to call
+            # get_startup_activity() again which will have a new time now.
+            self.signal_change(needs_save=False)
+            self._update_retry_time_dc = None
+
+    @returns_unicode
+    def get_reason_failed(self):
+        """Returns the reason for the failure of this download.  This
+        should only be called when the download is in the failed state.
         """
         if not self.get_state() == u'failed':
-            msg = u"getReasonFailed() called on a non-failed downloader"
+            msg = u"get_reason_failed() called on a non-failed downloader"
             raise ValueError(msg)
         self.confirm_db_thread()
-        return self.status['reasonFailed']
+        return self.status.get('reasonFailed', _("Unknown"))
 
-    @returnsUnicode
-    def getShortReasonFailed(self):
+    @returns_unicode
+    def get_short_reason_failed(self):
         if not self.get_state() == u'failed':
-            msg = u"getShortReasonFailed() called on a non-failed downloader"
+            msg = u"get_short_reason_failed() called on a non-failed downloader"
             raise ValueError(msg)
         self.confirm_db_thread()
-        return self.status['shortReasonFailed']
+        return self.status.get('shortReasonFailed', _("Unknown"))
 
-    @returnsUnicode
+    @returns_unicode
     def get_url(self):
         """Returns the URL we're downloading
         """
         self.confirm_db_thread()
         return self.url
 
-    @returnsUnicode    
+    @returns_unicode
     def get_state(self):
-        """Returns the state of the download: downloading, paused, stopped,
-        failed, or finished
+        """Returns the state of the download: downloading, paused,
+        stopped, failed, or finished.
         """
         self.confirm_db_thread()
         return self.state
 
-    def isFinished(self):
-        return self.get_state() in (u'finished', u'uploading', u'uploading-paused')
+    def is_finished(self):
+        return self.get_state() in (u'finished', u'uploading',
+                                    u'uploading-paused')
 
-    def getTotalSize(self):
-        """Returns the total size of the download in bytes
+    def get_total_size(self):
+        """Returns the total size of the download in bytes.
         """
         self.confirm_db_thread()
-        return self.status.get(u'totalSize', -1)
+        return self.status.get('totalSize', -1)
 
     def get_current_size(self):
-        """Returns the current amount downloaded in bytes
+        """Returns the current amount downloaded in bytes.
         """
         self.confirm_db_thread()
-        return self.status.get(u'currentSize', 0)
+        return self.status.get('currentSize', 0)
 
-    @returnsFilename
+    @returns_filename
     def get_filename(self):
-        """Returns the filename that we're downloading to. Should not be
+        """Returns the filename that we're downloading to.  Should not be
         called until state is "finished."
         """
         self.confirm_db_thread()
+        # FIXME - FilenameType('') is a bogus value, but looks like a
+        # filename.  should return None.
         return self.status.get('filename', FilenameType(''))
 
     def setup_restored(self):
         self._save_later_dc = None
+        self._update_retry_time_dc = None
         self.deleteFiles = True
         self.itemList = []
         if self.dlid == 'noid':
@@ -611,25 +650,37 @@ URL was %s""" % self.url
         self._recalc_state()
 
     def _recalc_state(self):
-        self.state = self.status.get('state', u'downloading')
+        new_state = self.status.get('state', u'downloading')
+        # avoid altering changed_attributes if we don't need to
+        if new_state != self.state:
+            self.state = new_state
 
-    def getUploadRatio(self):
+    def get_upload_ratio(self):
         size = self.get_current_size()
         if size == 0:
             return 0
         return self.status.get('uploaded', 0) / size
-    
-    def restartIfNeeded(self):
+
+    def restart_on_startup_if_needed(self):
+        if not self.id_exists():
+            return
+        if _downloads.has_key(self.dlid):
+            # something has caused us to restart already, (for
+            # example, the user selects "resume seeding").  squelch
+            # any automatic behaviour (#12462)
+            return
         if self.get_state() in (u'downloading', u'offline'):
             self.restart()
         if self.get_state() in (u'uploading'):
-            if self.manualUpload or self.getUploadRatio() < 1.5:
+            if ((self.manualUpload
+                 or (config.get(prefs.LIMIT_UPLOAD_RATIO)
+                     and self.get_upload_ratio() < config.get(prefs.UPLOAD_RATIO)))):
                 self.restart()
             else:
-                self.stopUpload()
+                self.stop_upload()
 
     def restart(self):
-        if len(self.status) == 0 or self.status.get('dlerType') is None:
+        if not self.status or self.status.get('dlerType') is None:
             if self.contentType == u"":
                 self.get_content_type()
             else:
@@ -643,19 +694,22 @@ URL was %s""" % self.url
                                                  dler_status)
             c.send()
 
-    def startUpload(self):
+    def start_upload(self):
+        """
+        Start an upload (seeding).
+        """
         if self.get_type() != u'bittorrent':
-            logging.warn("called startUpload for non-bittorrent downloader")
+            logging.warn("called start_upload for non-bittorrent downloader")
             return
         if self.child_deleted:
             title = "Can't Resume Seeding"
             msg = ("Seeding cannot resume because part of this torrent "
-                    "has been deleted.")
+                   "has been deleted.")
             dialogs.MessageBoxDialog(title, msg).run()
             return
         if self.get_state() not in (u'finished', u'uploading-paused'):
-            logging.warn("called startUpload when downloader state "
-                        "is: %s", self.get_state())
+            logging.warn("called start_upload when downloader state is: %s",
+                         self.get_state())
             return
         self.manualUpload = True
         if _downloads.has_key(self.dlid):
@@ -669,7 +723,7 @@ URL was %s""" % self.url
             self.restart()
             self.signal_change()
 
-    def stopUpload(self):
+    def stop_upload(self):
         """
         Stop uploading/seeding and set status as "finished".
         """
@@ -683,7 +737,7 @@ URL was %s""" % self.url
         self.after_changing_status()
         self.signal_change()
 
-    def pauseUpload(self):
+    def pause_upload(self):
         """
         Stop uploading/seeding and set status as "uploading-paused".
         """
@@ -731,7 +785,7 @@ def kill_uploaders(*args):
     torrent_limit = config.get(prefs.UPSTREAM_TORRENT_LIMIT)
     auto_uploads = list(RemoteDownloader.auto_uploader_view())
     for dler in auto_uploads[torrent_limit:]:
-        dler.stopUpload()
+        dler.stop_upload()
 
 def config_change_uploaders(key, value):
     if key == prefs.UPSTREAM_TORRENT_LIMIT.key:
@@ -758,7 +812,7 @@ class DownloadDaemonStarter(object):
 
     def restart_downloads(self):
         for downloader in self.downloads_at_startup:
-            downloader.restartIfNeeded()
+            downloader.restart_on_startup_if_needed()
 
     def shutdown(self, callback):
         self.shutdown_callback = callback
@@ -776,8 +830,8 @@ class DownloadDaemonStarter(object):
 def init_controller():
     """Intializes the download daemon controller.
 
-    This doesn't actually start up the downloader daemon, that's done in
-    startup_downloader.  Commands will be queued until then.
+    This doesn't actually start up the downloader daemon, that's done
+    in startup_downloader.  Commands will be queued until then.
     """
     global daemon_starter
     daemon_starter = DownloadDaemonStarter()
@@ -785,10 +839,10 @@ def init_controller():
 def startup_downloader():
     """Initialize the downloaders.
 
-    This method currently does 2 things.  It deletes any stale files self in
-    Incomplete Downloads, then it restarts downloads that have been restored
-    from the database.  It must be called before any RemoteDownloader objects
-    get created.
+    This method currently does 2 things.  It deletes any stale files
+    self in Incomplete Downloads, then it restarts downloads that have
+    been restored from the database.  It must be called before any
+    RemoteDownloader objects get created.
     """
     daemon_starter.startup()
 
@@ -826,7 +880,7 @@ def get_downloader_for_item(item):
     if not channelName:
         channelName = None
     if url.startswith(u'file://'):
-        path = getFileURLPath(url)
+        path = get_file_url_path(url)
         try:
             get_torrent_info_hash(path)
         except ValueError:
@@ -834,15 +888,16 @@ def get_downloader_for_item(item):
         except IOError:
             return None
         else:
-            return RemoteDownloader(url, item, u'application/x-bittorrent', channelName=channelName)
+            return RemoteDownloader(url, item, u'application/x-bittorrent',
+                                    channelName=channelName)
     else:
         return RemoteDownloader(url, item, channelName=channelName)
 
 def ensure_downloaders_saved():
     """Make sure any RemoteDownloaders with pending changes get saved.
 
-    For performance reasons, RemoteDownloader objects don't save to disk every
-    time their status dict is updated.
+    For performance reasons, RemoteDownloader objects don't save to
+    disk every time their status dict is updated.
     """
     for downloader in RemoteDownloader.make_view():
         downloader._save_now()
