@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -244,7 +244,9 @@ def miro_allfiles(directory):
     except OSError:
         return []
     for name in listing:
-        if name.startswith('.') or name.lower() == 'thumbs.db':
+        name_lower = name.lower()
+        if (name.startswith('.') or name_lower == 'thumbs.db' or
+                name_lower == "incomplete downloads"):
             # thumbs.db is a windows file that speeds up thumbnails.  We know
             # it's not a movie file.
             continue
