@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -44,12 +44,18 @@ from miro import displaytext
 from miro.plat import resources
 from miro.plat import screensaver
 from miro.frontends.widgets.gtk.window import Window, WrappedWindow
-from miro.frontends.widgets.gtk.widgetset import Widget, VBox, Label, HBox, Alignment, Background, DrawingArea, ImageSurface, Image, CustomButton
+from miro.frontends.widgets.gtk.widgetset import (Widget, VBox, Label, HBox,
+                                                  Alignment, Background,
+                                                  DrawingArea, ImageSurface,
+                                                  Image, CustomButton)
 from miro.frontends.widgets.gtk.persistentwindow import PersistentWindow
 
 BLACK = (0.0, 0.0, 0.0)
 WHITE = (1.0, 1.0, 1.0)
 
+# Global VideoWidget object.  We re-use so we can re-use our PersistentWindow
+video_widget = None
+
 class ClickableLabel(Widget):
     """This is like a label and reimplements many of the Label things, but
     it's an EventBox with a Label child widget.
@@ -74,7 +80,7 @@ class ClickableLabel(Widget):
         self.create_signal('clicked')
 
     def on_click(self, widget, event):
-        self.emit('clicked')
+        self.emit('clicked', event)
         return True
 
     def on_enter_notify(self, widget, event):
@@ -104,12 +110,27 @@ class ClickableImageButton(CustomButton):
         CustomButton.__init__(self)
         self.image = ImageSurface(Image(image_path))
 
+        self.wrapped_widget_connect('enter-notify-event', self.on_enter_notify)
+        self.wrapped_widget_connect('leave-notify-event', self.on_leave_notify)
+        self.wrapped_widget_connect('button-release-event', self.on_click)
+
     def size_request(self, layout):
         return self.image.width, self.image.height
 
     def draw(self, context, layout):
         self.image.draw(context, 0, 0, self.image.width, self.image.height)
 
+    def on_click(self, widget, event):
+        self.emit('clicked', event)
+        return True
+
+    def on_enter_notify(self, widget, event):
+        self._widget.window.set_cursor(gtk.gdk.Cursor(gtk.gdk.HAND1))
+
+    def on_leave_notify(self, widget, event):
+        if self._widget.window:
+            self._widget.window.set_cursor(None)
+
 class NullRenderer:
     def __init__(self):
         pass
@@ -136,7 +157,7 @@ def make_label(text, handler, visible=True):
     return lab
 
 def make_image_button(image_path, handler):
-    b = ClickableImageButton(image_path)
+    b = ClickableImageButton(resources.path(image_path))
     b.connect('clicked', handler)
     return b
 
@@ -212,6 +233,9 @@ class VideoWidget(Widget):
         self._widget.add_events(gtk.gdk.BUTTON_PRESS_MASK)
         renderer.set_widget(self._widget)
 
+    def destroy(self):
+        self._widget.destroy()
+
 class Divider(DrawingArea):
     def size_request(self, layout):
         return (1, 25)
@@ -242,11 +266,7 @@ class VideoDetailsWidget(Background):
 
         outer_hbox = HBox(5)
 
-        if info.is_external:
-            self._delete_link = make_label(_("Delete"), self.handle_delete, True)
-            outer_hbox.pack_start(_align_middle(self._delete_link))
-
-        else:
+        if not info.is_external:
             if info.expiration_date is not None:
                 text = displaytext.expiration_date(info.expiration_date)
                 self._expiration_label = Label(text)
@@ -259,18 +279,34 @@ class VideoDetailsWidget(Background):
             outer_hbox.pack_start(_align_middle(lab))
             outer_hbox.pack_start(_align_middle(Divider(), top_pad=3, bottom_pad=3, left_pad=5, right_pad=5))
 
-            self._delete_link = make_label(_("Delete"), self.handle_delete)
-            outer_hbox.pack_start(_align_middle(self._delete_link))
+        self._subtitles_link = make_label(_("Subtitles"),
+                                          self.handle_subtitles)
+        outer_hbox.pack_start(_align_middle(self._subtitles_link))
+        subtitles_image = make_image_button('images/subtitles_down.png',
+                                            self.handle_subtitles)
+        outer_hbox.pack_start(_align_middle(subtitles_image))
+
+        outer_hbox.pack_start(_align_middle(Divider(), top_pad=3, bottom_pad=3, left_pad=5, right_pad=5))
+
+        self._delete_link = make_label(_("Delete"), self.handle_delete)
+        outer_hbox.pack_start(_align_middle(self._delete_link))
+
+        if not info.is_external:
             outer_hbox.pack_start(_align_middle(Divider(), top_pad=3, bottom_pad=3, left_pad=5, right_pad=5))
 
-            self._share_link = make_label(_("Share"), self.handle_share, info.has_sharable_url)
+            self._share_link = make_label(_("Share"), self.handle_share,
+                                          info.has_sharable_url)
             outer_hbox.pack_start(_align_middle(self._share_link))
             outer_hbox.pack_start(_align_middle(Divider(), top_pad=3, bottom_pad=3, left_pad=5, right_pad=5))
 
             if info.commentslink:
-                self._permalink_link = make_label(_("Comments"), self.handle_commentslink, info.commentslink)
+                self._permalink_link = make_label(_("Comments"),
+                                                  self.handle_commentslink,
+                                                  info.commentslink)
             else:
-                self._permalink_link = make_label(_("Permalink"), self.handle_permalink, info.permalink)
+                self._permalink_link = make_label(_("Permalink"),
+                                                  self.handle_permalink,
+                                                  info.permalink)
             outer_hbox.pack_start(_align_middle(self._permalink_link))
 
         outer_hbox.pack_start(_align_middle(Divider(), top_pad=3, bottom_pad=3, left_pad=5, right_pad=5))
@@ -278,12 +314,14 @@ class VideoDetailsWidget(Background):
         if app.playback_manager.detached_window is not None:
             popin_link = make_label(_("Pop-in"), self.handle_popin_popout)
             outer_hbox.pack_start(_align_middle(popin_link))
-            popin_image = make_image_button(resources.path('images/popin.png'), self.handle_popin_popout)
+            popin_image = make_image_button('images/popin.png',
+                                            self.handle_popin_popout)
             outer_hbox.pack_start(_align_middle(popin_image))
         else:
             popout_link = make_label(_("Pop-out"), self.handle_popin_popout)
             outer_hbox.pack_start(_align_middle(popout_link))
-            popout_image = make_image_button(resources.path('images/popout.png'), self.handle_popin_popout)
+            popout_image = make_image_button('images/popout.png',
+                                             self.handle_popin_popout)
             outer_hbox.pack_start(_align_middle(popout_image))
 
         self.add(_align_right(outer_hbox, left_pad=15, right_pad=15))
@@ -294,28 +332,89 @@ class VideoDetailsWidget(Background):
     def show(self):
         self._widget.show()
 
-    def handle_popin_popout(self, widget):
+    def handle_popin_popout(self, widget, event=None):
         if app.playback_manager.is_fullscreen:
             app.playback_manager.exit_fullscreen()
         app.playback_manager.toggle_detached_mode()
 
-    def handle_keep(self, widget):
+    def handle_keep(self, widget, event):
         messages.KeepVideo(self.item_info.id).send_to_backend()
         self._widget.window.set_cursor(None)
 
-    def handle_delete(self, widget):
+    def handle_delete(self, widget, event):
         item_info = self.item_info
         self.reset()
         app.playback_manager.on_movie_finished()
         app.widgetapp.remove_items([item_info])
 
-    def handle_commentslink(self, widget):
+    def handle_subtitles(self, widget, event):
+        tracks = []
+        menu = gtk.Menu()
+
+        tracks = app.video_renderer.get_subtitle_tracks()
+
+        if len(tracks) == 0:
+            child = gtk.MenuItem(_("None Available"))
+            child.set_sensitive(False)
+            child.show()
+            menu.append(child)
+        else:
+            enabled_track = app.video_renderer.get_enabled_subtitle_track()
+
+            first_child = None
+            for i, lang in tracks:
+                child = gtk.RadioMenuItem(first_child, lang)
+                if enabled_track == i:
+                    child.set_active(True)
+                child.connect('activate', self.handle_subtitle_change, i)
+                child.show()
+                menu.append(child)
+                if first_child == None:
+                    first_child = child
+
+            sep = gtk.SeparatorMenuItem()
+            sep.show()
+            menu.append(sep)
+
+            child = gtk.RadioMenuItem(first_child, _("Disable Subtitles"))
+            if enabled_track == -1:
+                child.set_active(True)
+            child.connect('activate', self.handle_disable_subtitles)
+            child.show()
+            menu.append(child)
+
+        sep = gtk.SeparatorMenuItem()
+        sep.show()
+        menu.append(sep)
+
+        child = gtk.MenuItem(_("Select a Subtitles file..."))
+        child.set_sensitive(True)
+        child.connect('activate', self.handle_select_subtitle_file)
+        child.show()
+        menu.append(child)
+
+        menu.popup(None, None, None, event.button, event.time)
+
+    def handle_disable_subtitles(self, widget):
+        if widget.active:
+            app.video_renderer.disable_subtitles()
+            app.widgetapp.window.on_playback_change(app.playback_manager)
+
+    def handle_subtitle_change(self, widget, index):
+        if widget.active:
+            app.video_renderer.enable_subtitle_track(index)
+            app.widgetapp.window.on_playback_change(app.playback_manager)
+
+    def handle_select_subtitle_file(self, widget):
+        app.playback_manager.open_subtitle_file()
+
+    def handle_commentslink(self, widget, event):
         app.widgetapp.open_url(self.item_info.commentslink)
 
-    def handle_share(self, widget):
+    def handle_share(self, widget, event):
         app.widgetapp.share_item(self.item_info)
 
-    def handle_permalink(self, widget):
+    def handle_permalink(self, widget, event):
         app.widgetapp.open_url(self.item_info.permalink)
 
     def update_info(self, item_info):
@@ -355,6 +454,7 @@ class VideoPlayer(player.Player, VBox):
     HIDE_CONTROLS_TIMEOUT = 2000
 
     def __init__(self):
+        global video_widget
         player.Player.__init__(self)
         VBox.__init__(self)
         if app.video_renderer is not None:
@@ -364,7 +464,9 @@ class VideoPlayer(player.Player, VBox):
 
         self.overlay = None
 
-        self._video_widget = VideoWidget(self.renderer)
+        if video_widget is None:
+            video_widget = VideoWidget(self.renderer)
+        self._video_widget = video_widget
         self.pack_start(self._video_widget, expand=True)
 
         self._video_details = VideoDetailsWidget()
@@ -386,6 +488,7 @@ class VideoPlayer(player.Player, VBox):
         app.info_updater.item_changed_callbacks.remove('manual',
                 'playback-list', self._on_items_changed)
         self._items_changed_callback = None
+        self.remove(self._video_widget)
 
     def _on_items_changed(self, message):
         for item_info in message.changed:
@@ -398,7 +501,7 @@ class VideoPlayer(player.Player, VBox):
 
     def set_item(self, item_info, success_callback, error_callback):
         self._video_details.set_video_details(item_info)
-        self.renderer.select_file(item_info.video_path, success_callback, error_callback)
+        self.renderer.select_file(item_info, success_callback, error_callback)
         self._item_id = item_info.id
 
     def get_elapsed_playback_time(self):
@@ -448,7 +551,8 @@ class VideoPlayer(player.Player, VBox):
                 'motion-notify-event', self.on_mouse_motion)
         self.videobox_motion_handler = self.overlay._window.connect(
                 'motion-notify-event', self.on_mouse_motion)
-        app.widgetapp.window.menubar.hide()
+        if not app.playback_manager.detached_window:
+            app.widgetapp.window.menubar.hide()
         self.schedule_hide_controls(self.HIDE_CONTROLS_TIMEOUT)
         # make sure all hide() calls go through, otherwise we get the wrong
         # size on windows (#10810)
@@ -538,3 +642,10 @@ class VideoPlayer(player.Player, VBox):
         self._widget.disconnect(self.motion_handler)
         self.cancel_hide_controls()
         _window().window.set_cursor(None)
+
+    def select_subtitle_file(self, sub_path, handle_successful_select):
+        app.video_renderer.select_subtitle_file(
+            app.playback_manager.get_playing_item(), 
+            sub_path,
+            handle_successful_select)
+        
