@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -796,6 +796,7 @@ class HeaderToolbar(widgetset.Background):
                     button.set_sort_state(SortBarButton.SORT_DOWN)
             else:
                 button.set_sort_state(SortBarButton.SORT_NONE)
+        self._ascending = ascending
 
     def _make_button(self, text, sort_key):
         button = SortBarButton(text)
@@ -807,7 +808,11 @@ class HeaderToolbar(widgetset.Background):
         if self._current_sort_key == sort_key:
             self._ascending = not self._ascending
         else:
-            self._ascending = False
+            # we want sort-by-name to default to alphabetical order
+            if sort_key == "name":
+                self._ascending = True
+            else:
+                self._ascending = False
             old_button = self._button_map[self._current_sort_key]
             old_button.set_sort_state(SortBarButton.SORT_NONE)
             self._current_sort_key = sort_key
