@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -34,8 +34,8 @@ from miro import app
 from miro.frontends.widgets import style
 from miro.frontends.widgets import imagepool
 from miro.frontends.widgets import widgetutil
-from miro.frontends.widgets import widgetconst
 from miro.frontends.widgets import imagebutton
+from miro.frontends.widgets.widgetconst import MAX_VOLUME
 from miro.plat.frontends.widgets import widgetset
 from miro.plat import resources
 
@@ -340,7 +340,6 @@ class ProgressSlider(widgetset.CustomSlider):
 class ProgressTimeline(widgetset.Background):
     def __init__(self):
         widgetset.Background.__init__(self)
-        self.background = widgetutil.ThreeImageSurface('display')
         self.duration = self.current_time = None
         self.info = PlaybackInfo()
         self.slider = ProgressSlider()
@@ -382,19 +381,36 @@ class ProgressTimeline(widgetset.Background):
         self.time.set_current_time(current_time)
         self.remaining_time.set_current_time(current_time)
 
+    def get_height(self, layout):
+        # this assumes that the height is 14 pixels of space plus the
+        # height of two labels--one for the time and one for the
+        # title.  we do the max thing so there's a minimum height that
+        # comes out of this.
+        layout.set_font(0.8)
+        sizer_text = layout.textbox("Foo")
+        dummy, height = sizer_text.get_size()
+        return max(40, 14 + (height * 2))
+
     def size_request(self, layout):
-        return -1, self.background.height
+        layout.set_font(0.8)
+        sizer_text = layout.textbox("Foo")
+        dummy, height = sizer_text.get_size()
+        return -1, self.get_height(layout)
 
     def draw(self, context, layout):
-        fraction = 1.0
-        if not self.get_window().is_active():
-            fraction = 0.5
-        self.background.draw(context, 0, 0, context.width, fraction)
+        if self.get_window().is_active():
+            c = (40.0 / 255.0, 40.0 / 255.0, 40.0 / 255.0)
+        else:
+            c = (145.0 / 255.0, 145.0 / 255.0, 145.0 / 255.0)
+
+        widgetutil.round_rect(context, 0, 0, context.width, context.height, 5)
+        context.set_color(c)
+        context.fill()
 
 class VolumeSlider(widgetset.CustomSlider):
     def __init__(self):
         widgetset.CustomSlider.__init__(self)
-        self.set_range(0.0, 1.0)
+        self.set_range(0.0, MAX_VOLUME)
         self.set_increments(0.05, 0.20)
         self.track = widgetutil.make_surface('volume_track')
         self.knob = widgetutil.make_surface('volume_knob')
@@ -420,8 +436,9 @@ class VolumeSlider(widgetset.CustomSlider):
         self.track.draw(context, 0, y, self.track.width, self.track.height)
 
     def draw_knob(self, context):
+        portion_right = self.get_value() / MAX_VOLUME
         x_max = context.width - self.slider_size()
-        slider_x = int(round(self.get_value() * x_max))
+        slider_x = int(round(portion_right * x_max))
         slider_y = (context.height - self.knob.height) / 2
         self.knob.draw(context, slider_x, slider_y, self.knob.width,
                 self.knob.height)
