@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -59,12 +59,14 @@ from miro.playlist import SavedPlaylist
 from miro.folder import FolderBase, ChannelFolder, PlaylistFolder
 from miro.xhtmltools import urlencode
 
-from miro.plat.utils import makeURLSafe
+from miro.plat.utils import make_url_safe
 
 import shutil
 
 class ViewTracker(object):
     """Handles tracking views for TrackGuides, TrackChannels, TrackPlaylist and TrackItems."""
+    type = None
+    InfoClass = None
 
     def __init__(self):
         self.trackers = []
@@ -99,6 +101,9 @@ class ViewTracker(object):
             message.send_to_frontend()
         self.reset_changes()
 
+    def make_changed_message(self, added, changed, removed):
+        raise NotImplementedError()
+
     def _make_new_info(self, obj):
         info = self.InfoClass(obj)
         self._last_sent_info[obj.id] = copy(info)
@@ -181,6 +186,9 @@ class TabTracker(ViewTracker):
         ViewTracker.__init__(self)
         self.send_whole_list = False
 
+    def get_tab_order(self):
+        raise NotImplementedError()
+
     def make_changed_message(self, added, changed, removed):
         return messages.TabsChanged(self.type, added, changed, removed)
 
@@ -271,6 +279,9 @@ class WatchedFolderTracker(ViewTracker):
 class ItemTrackerBase(ViewTracker):
     InfoClass = messages.ItemInfo
 
+    def __init__(self):
+        ViewTracker.__init__(self)
+
     def make_changed_message(self, added, changed, removed):
         return messages.ItemsChanged(self.type, self.id,
                 added, changed, removed)
@@ -415,6 +426,12 @@ class CountTracker(object):
         self.tracker.connect('added', self.on_count_changed)
         self.tracker.connect('removed', self.on_count_changed)
 
+    def get_view(self):
+        raise NotImplementedError()
+
+    def make_message(self, count):
+        raise NotImplementedError()
+
     def on_count_changed(self, tracker, obj):
         self.send_message()
 
@@ -591,6 +608,15 @@ class BackendMessageHandler(messages.MessageHandler):
         except database.ObjectNotFoundError:
             logging.warning("handle_set_item_resume_time: can't find item by id %s", message.id)
 
+    def handle_set_item_media_type(self, message):
+        for id in message.video_ids:
+            try:
+                item_ = item.Item.get_by_id(id)
+            except database.ObjectNotFoundError:
+                logging.warn("SetItemMediaType: Item not found -- %s", id)
+                continue
+            item_.set_file_type(message.media_type)
+
     def handle_set_feed_expire(self, message):
         channel_info = message.channel_info
         expire_type = message.expire_type
@@ -738,7 +764,7 @@ class BackendMessageHandler(messages.MessageHandler):
         except database.ObjectNotFoundError:
             logging.warn("site not found: %s" % message.id)
         else:
-            if site.get_default():
+            if site.is_default():
                 raise ValueError("Can't delete default site")
             site.remove()
 
@@ -926,7 +952,7 @@ class BackendMessageHandler(messages.MessageHandler):
             tracker.send_whole_list = True
 
     def handle_new_watched_folder(self, message):
-        url = u"dtv:directoryfeed:%s" % makeURLSafe(message.path)
+        url = u"dtv:directoryfeed:%s" % make_url_safe(message.path)
         if not get_feed_by_url(url):
             feed.Feed(url)
         else:
@@ -960,10 +986,10 @@ class BackendMessageHandler(messages.MessageHandler):
         commandline.parse_command_line_args(message.filenames)
 
     def handle_add_files(self, message):
+        # exclude blank or None values
+        good_files = [f for f in message.filenames if f]
         # add all files to Miro in the manualFeed
-        for mem in message.filenames:
-            if mem:
-                commandline.add_video(mem, False)
+        commandline.add_videos(good_files)
 
     def handle_check_version(self, message):
         up_to_date_callback = message.up_to_date_callback
@@ -1098,7 +1124,7 @@ class BackendMessageHandler(messages.MessageHandler):
         """Pauses all downloading and uploading items"""
         for item_ in item.Item.downloading_view():
             if item_.is_uploading():
-                item_.pauseUpload()
+                item_.pause_upload()
             else:
                 item_.pause()
 
@@ -1114,7 +1140,7 @@ class BackendMessageHandler(messages.MessageHandler):
         """Resumes downloading and uploading items"""
         for item_ in item.Item.paused_view():
             if item_.is_uploading_paused():
-                item_.startUpload()
+                item_.start_upload()
             else:
                 item_.resume()
 
@@ -1129,7 +1155,7 @@ class BackendMessageHandler(messages.MessageHandler):
     def handle_cancel_all_downloads(self, message):
         for item_ in item.Item.download_tab_view():
             if item_.is_uploading() or item_.is_uploading_paused():
-                item_.stopUpload()
+                item_.stop_upload()
             else:
                 item_.expire()
 
@@ -1147,7 +1173,7 @@ class BackendMessageHandler(messages.MessageHandler):
             elif item_.is_uploading():
                 logging.warn("%s is already uploading", item_)
             else:
-                item_.startUpload()
+                item_.start_upload()
 
     def handle_stop_upload(self, message):
         try:
@@ -1163,7 +1189,7 @@ class BackendMessageHandler(messages.MessageHandler):
             elif not item_.is_uploading():
                 logging.warn("%s is already stopped", item_)
             else:
-                item_.stopUpload()
+                item_.stop_upload()
 
     def handle_keep_video(self, message):
         try:
@@ -1213,6 +1239,23 @@ class BackendMessageHandler(messages.MessageHandler):
         else:
             item_.set_title(message.new_name)
 
+    def handle_edit_item(self, message):
+        try:
+            item_ = item.Item.get_by_id(message.item_id)
+        except database.ObjectNotFoundError:
+            logging.warn("EditItem: Item not found -- %s", message.item_id)
+            return
+        change_dict = message.change_dict
+
+        if "name" in change_dict:
+            item_.set_title(change_dict["name"])
+
+        if "description" in change_dict:
+            item_.set_description(change_dict["description"])
+
+        if "file_type" in change_dict:
+            item_.set_file_type(change_dict["file_type"])
+
     def handle_revert_feed_title(self, message):
         try:
             feed_object = feed.Feed.get_by_id(message.id)
@@ -1221,14 +1264,6 @@ class BackendMessageHandler(messages.MessageHandler):
         else:
             feed_object.revert_title()
 
-    def handle_revert_item_title(self, message):
-        try:
-            item_ = item.Item.get_by_id(message.id)
-        except database.ObjectNotFoundError:
-            logging.warn("RevertItemTitle: Item not found -- %s", message.id)
-        else:
-            item_.revert_title()
-
     def handle_autodownload_change(self, message):
         try:
             feed_ = feed.Feed.get_by_id(message.id)
@@ -1327,22 +1362,20 @@ class BackendMessageHandler(messages.MessageHandler):
             logging.info("migrating %s", download.get_filename())
             download.migrate(new_path)
         # Pass in case they don't exist or are not empty:
+        # FIXME - these will never work since they're directory trees
+        # and fileutil.rmdir calls os.rmdir which only removes non-empty
+        # directories.
         try:
             fileutil.rmdir(os.path.join(old_path, 'Incomplete Downloads'))
-        except (SystemExit, KeyboardInterrupt):
-            raise
-        except:
+        except OSError:
             pass
         try:
             fileutil.rmdir(old_path)
-        except (SystemExit, KeyboardInterrupt):
-            raise
-        except:
+        except OSError:
             pass
         m = messages.MigrationProgress(migration_count, migration_count, True)
         m.send_to_frontend()
 
-
     def handle_report_crash(self, message):
         app.controller.send_bug_report(message.report, message.text,
                                        message.send_report)
